Lua_CollectionBookFlashPanel = class("Lua_CollectionBookFlashPanel", Lua_DisplayObject);
function Lua_CollectionBookFlashPanel:ctor(p)
	self:superCall("ctor", p, "CollectionBookFlashPanel_skin");
end

function Lua_CollectionBookFlashPanel:buildShowItem()
	self:superCall("buildShowItem");

	self.showPageCardCount = 6; -- 页面展示卡牌数量
	self.cardListIndex = 1;
    self:updateCardList();
	self.tipsIcon:addClickFuntion(self, self.onClickTipsIcon); -- 提示Icon
	self.lastPageSp:addClickFuntion(self, self.onClickLastPageBtn); -- 上一页
	self.nextPageSp:addClickFuntion(self, self.onClickNextPageBtn); -- 下一页

	self:addLuaEvent("UPDATE_CBFLASHCOUNT", self, self.updateCardList); -- 卡牌放入卡册更新
	self:addLuaEvent("UPDATE_CBCARDDETAIL_ACTIVECARD", self, self.updateCardList); -- 卡牌激活更新
end

function Lua_CollectionBookFlashPanel:onScreenResize(adaptHeight)
	self:superCall("onScreenResize", adaptHeight);
	-- self:updateCardPos();
	self:updateCardListPos();
end

function Lua_CollectionBookFlashPanel:updateCardItemPos(index)
	local startX = -229;
	local startY = -373;
	local posX, posY;
	local distanceY = 65;
	if self.adaptHeight < 0 then
		distanceY = distanceY + self.adaptHeight;
	end
	distanceY = distanceY < 0 and 0 or distanceY;
	distanceY = distanceY + 470;
	posX = startX + (index - 1) % 3 * 231;
	posY = startY - Mathf.Floor((index - 1) / 3) * distanceY;
	return posX, posY;
end

function Lua_CollectionBookFlashPanel:getCardItem(index)
	if self.cardItemList == nil then
		self.cardItemList = {};
	end

	local item = self.cardItemList[index];
	if item == nil then
		item = Lua_CollectionWeaponFlashCardItem.new(self.content);
		item:setRectAnchor(1);
		local posX, posY = self:updateCardItemPos(index);
		item:setLocation(posX, posY);
		self.cardItemList[index] = item;
	end
	return item;
end

function Lua_CollectionBookFlashPanel:updateCardListPos()
	local item;
	local posX, posY;
	for i = 1, #self.cardItemList do
		item = self.cardItemList[i];
		posX, posY = self:updateCardItemPos(i)
		item:setLocation(posX, posY);
	end
end

function Lua_CollectionBookFlashPanel:updateCardItemList()
	local index;
	local cardId;
	local cardItem;
	for i = 1, self.showPageCardCount do
		index = self.cardListIndex + (i - 1);
		cardId = self.cardDataList[index];
		cardItem = self:getCardItem(i);
		if cardId ~= nil then
			cardItem:setData(cardId);
			cardItem:setEnable(true);
		else
			cardItem:setEnable(false);
		end
	end
end

function Lua_CollectionBookFlashPanel:updateCardList()
	self.cardDataList = DataCenter.collectionBookData:getFlashCardIdListByType(1);
	self.cardListCount = #self.cardDataList;
	local isNoneCard = self.cardListCount == 0;
	self.noneCardSp:setEnable(isNoneCard);
	self.noneCardTxt:setEnable(isNoneCard);
	self:updateCardItemList();
	self:updatePageNumTxt();
end

function Lua_CollectionBookFlashPanel:updatePageNumTxt()
	local num = Mathf.Ceil(self.cardListIndex / self.showPageCardCount);
	local curPageNum = num == 0 and 1 or num;

	num = Mathf.Ceil(self.cardListCount / self.showPageCardCount);
	local totalPageNum = num == 0 and 1 or num;
	self.pageNumTxt.text = LanUtil.formateStr(410024, curPageNum, totalPageNum);
end

function Lua_CollectionBookFlashPanel:onClickLastPageBtn()
	local index = self.cardListIndex - self.showPageCardCount;
	if index < 1 then
		OperateAlert.showLangValue(410025);
		return;
	end
	self.cardListIndex = index;
	self:updateCardItemList();
	self:updatePageNumTxt();
end

function Lua_CollectionBookFlashPanel:onClickNextPageBtn()
	local index = self.cardListIndex + self.showPageCardCount;
	if index > self.cardListCount then
		OperateAlert.showLangValue(410026);
		return;
	end

	self.cardListIndex = index;
	self:updateCardItemList();
	self:updatePageNumTxt();
end

function Lua_CollectionBookFlashPanel:onClickTipsIcon()
	local tipsData = { des = LanUtil.getValue(410032), posX = 174, posY = -241 };
	Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
end

function Lua_CollectionBookFlashPanel:dispose()
	if self.cardItemList ~= nil then
		for i = 1, #self.cardItemList do
			self.cardItemList[i]:dispose();
			self.cardItemList[i] = nil;
		end
		self.cardItemList = nil;
	end

	self:superCall("dispose");
end






























--收藏册闪卡Vo
Lua_CollectionWeaponFlashCardItem = class("Lua_CollectionWeaponFlashCardItem", Lua_DisplayObject);
function Lua_CollectionWeaponFlashCardItem:ctor(p)
    self:superCall("ctor", p, "CollectionWeaponFlashCardItem_skin");
end

function Lua_CollectionWeaponFlashCardItem:buildShowItem()
	self:superCall("buildShowItem");

	self.flashItem = Lua_CommonFlashCardItem.new(self.content);
	self.flashItem.canRotate = false; -- 是否可旋转
	self.flashItem:setCanClick(false);
	self.flashItem:setScale(0.26, 0.26);
	self.flashItem:setLocation(-2, 46);

	self.cardBg.clickScale = false;
    self.cardBg:addMouseUpFuntion(self, self.onMouseUp);
    self.cardBg:addMousDownFuntion(self, self.onMouseDown);
end

function Lua_CollectionWeaponFlashCardItem:setData(data)
	if data == nil then
		return;
	end

	self.data = data;
	if DataCenter.collectionBookUtil:getSingleCardConfigById(self.data) then
		local flashId = DataCenter.collectionBookUtil:getCardConfigByCardIdAndType(self.data, Lua_CollectionBookUtil.FLASH_ID);
		if flashId == nil then return; end

		local flashInfo = Lua_FlashCardVo.new(flashId);
		self.flashItem:setData(flashInfo);

		local str;
		local descConfig;
		self.timeTxt.text = DataCenter.collectionBookData:getUnlockTimeStr(2, self.data, false);
		self.nameTxt.text = DataCenter.collectionBookUtil:getAdditionDesc(self.data);

		descConfig = DataCenter.collectionBookUtil:getCardConfigByCardIdAndType(self.data, Lua_CollectionBookUtil.CARD_PROP);
		str = descConfig ~= nil and descConfig.attack ~= nil and descConfig.attack or nil;
		self.attachTxt.text = LanUtil.formateStr(410050,str);
		str = descConfig ~= nil and descConfig.health ~= nil and descConfig.health or nil;
		self.lifeTxt.text = LanUtil.formateStr(410049, str);

		-- 特效
		local isShowEffect = DataCenter.collectionBookUtil:checkShowEffectByCardId(self.data);
		self.flashItem:showEffect(isShowEffect, "ui_scc_sk_0002", 0, 0, 1);
	end
end

function Lua_CollectionWeaponFlashCardItem:onMouseUp()
	self:setScale(1, 1, 1);
	self:onPressClick();
end

function Lua_CollectionWeaponFlashCardItem:onMouseDown()
	self:setScale(1.1, 1.1, 1.1);
end

function Lua_CollectionWeaponFlashCardItem:onPressClick()
	Lua_WindowUtil.openWin("Lua_CollectionBookCardDetailWindow", Lua_WinParam.ACTION_OPEN, tonumber(self.data));
end

function Lua_CollectionWeaponFlashCardItem:dispose()
	if self.flashItem ~= nil then
		self.flashItem:dispose();
		self.flashItem = nil;
	end
	self:superCall("dispose");
end