Lua_CollectionBookRankPanel = class("Lua_CollectionBookRankPanel", Lua_DisplayObject);
function Lua_CollectionBookRankPanel:ctor(p)
	self:superCall("ctor", p, "CollectionBookRankPanel_skin");
end

function Lua_CollectionBookRankPanel:buildShowItem()
	self:superCall("buildShowItem");

	self.tweenIdTab = {3057, 3058, 3059} 
	self.roleInfoPanel = Lua_RoleInfoPanel.new(self.content);
	self.roleInfoPanel:setRectAnchor(1);
	self.panelBg:SetDimensions(MainWinDefine.DEFAULT_WIDTH, 1339 + self.adaptHeight);

	self.topRankList = {};
	self.rankList = Lua_DragList.new(self.content, 687, 530 + self.adaptHeight, Lua_AxisDefine.Vertical);
	self.rankList:setListCell(Lua_CollectionBookRankItem, 687, 124, 1);
    self.rankList:setLocation(-3, -182, 0);
    self.rankList.tweenId = 2010;

    self.myAvatarItem = Lua_AvatarItem.new(self.content);
	self.myAvatarItem:setScale(0.7, 0.7);
	self.myAvatarItem:setLocation(-149, 187, 0);
	self.myAvatarItem:setRectAnchor(7);
	self.myAvatarItem:setAvatarClick(self, self.onMyAvatarClick);

	self.myAdmireSp:addClickFuntion(self, self.onClickMyAdmireSp);
	self:addLuaEvent("OPEN_CBRANKPANEL", self, self.updateRankInfo);
	self:addLuaEvent("COLLECTIONBOOK_UPDATE_RANK_OVERDAY", self, self.updateRankOverDay);
	Lua_ProxyManager.getProxy("Lua_CollectionBookProxy"):sGetCBRankInfo();
end

function Lua_CollectionBookRankPanel:playTween()
	if self.rankList ~= nil and self.bOpen then
		self.rankList.showTween = true;
		self.rankList:playTween();
		self:playRankTween();
	end
end

function Lua_CollectionBookRankPanel:updateRankInfo(msg)
	local item;
	local obj;
	local topRanks = {};
	local residueRanks = {};
	local rankList = msg.ranker_list;
	for i = 1, #rankList do
		if i <= 3 then
			topRanks[i] = rankList[i];
		else
			residueRanks[i - 3] = rankList[i];
		end
	end

	local count = #topRanks;
	if count < 3 then
		for i = count + 1, 3 do
			topRanks[i] = { rank = i};
		end
	end
	count = #residueRanks;
	local showRankLimit = DataCenter.collectionBookUtil.showRankLimit - 3;
	if count < showRankLimit then
		for i = count + 1, showRankLimit do
			residueRanks[i] = { rank = i + 3};
		end
	end

	for i = 1, #topRanks do
		obj = topRanks[i];
		item = self.topRankList[i];
		if item == nil then
			item = Lua_CollectionBookRankTopItem.new(self.content, i);
			item:setRectAnchor(1);
			item.content.name = "Lua_CollectionBookRankTopItem"..i;
			self.topRankList[i] = item;
		end
		item:setData(obj);
	end

	if not self.bOpen then 
		self:playRankTween();
		self.bOpen = true;
	end

	self.rankList:setArrayData(residueRanks);

	obj = msg.self_ranker;
	self.myNameTxt.text = obj.player_show.name;
	self.mydescTxt_1.text = LanUtil.formateStr(410021, obj.card_amount);
	self.mydescTxt_2.text = LanUtil.formateStr(410022, obj.flash_amount);
	self.myAdmireCountTxt.text = obj.like_num;

	self.myAvatarItem:setRoleId(obj.player_show.id);
	self.myAvatarItem:setRoleDressUp(obj.player_show.dress_info, true);
	self.myAvatarItem:setRoleLevel2(obj.player_show.level);

	if obj.rank == 0 then
		self.myNoneRankSp:setEnable(true);
		if self.myRankNum ~= nil then
			self.myRankNum:setEnable(false);
		end
	else
		self.myNoneRankSp:setEnable(false);
		if self.myRankNum == nil then
			self.myRankNum = Lua_NumberImage.new(self.content);
			self.myRankNum:setRectAnchor(7);
			self.myRankNum:setLocation(-274, 179, 0);
			self.myRankNum.numOffsetX = -4;
			self.myRankNum.numAtlas = "number";
			self.myRankNum.preStr = "ui_djc_title_0";
		end
		self.myRankNum:setEnable(true);
		self.myRankNum.num = obj.rank;
	end
end

function Lua_CollectionBookRankPanel:playRankTween()
	if self.topRankList ~= nil then
		local item; 
		local tweenId = 3050;
		for i = 1, #self.topRankList do
			tweenId = self.tweenIdTab[i] or tweenId;
			self:removeTweenByIndex(i);
			item = self.topRankList[i];
			DataCenter.winTweenManager:playWinTween(tweenId, item.content.transform);
		end
	end
end

function Lua_CollectionBookRankPanel:removeTweenByIndex(index)
	if self.topRankList ~= nil and self.topRankList[index] ~= nil then
		local item = self.topRankList[index];
		TweenUtil.getInstance():stop(item.content.transform);
	end
end

function Lua_CollectionBookRankPanel:removeAllTween()
	if self.topRankList ~= nil then
		for i = 1, #self.topRankList do
			self:removeTweenByIndex(i);
		end
	end
end

function Lua_CollectionBookRankPanel:onMyAvatarClick()
	OperateAlert.showLangValue(440010);
end

function Lua_CollectionBookRankPanel:onClickMyAdmireSp()
	OperateAlert.showLangValue(410007);
end

function Lua_CollectionBookRankPanel:showWin(param)
	self:superCall("showWin", param);
end

function Lua_CollectionBookRankPanel:onScreenResize(adaptHeight)
	if self.adaptHeight ~= adaptHeight then
		self:superCall("onScreenResize", adaptHeight);
		self.rankList:setContentRect(687, 530 + self.adaptHeight);
		self.panelBg:SetDimensions(MainWinDefine.DEFAULT_WIDTH, 1339 + self.adaptHeight);
	end
end

-- 跨天更新排行榜
function Lua_CollectionBookRankPanel:updateRankOverDay()
	Lua_ProxyManager.getProxy("Lua_CollectionBookProxy"):sAdmireOtherPlayer(0); 
    Lua_ProxyManager.getProxy("Lua_CollectionBookProxy"):sGetCBRankInfo(); 
end

function Lua_CollectionBookRankPanel:dispose()
	self:removeAllTween();
	if self.roleInfoPanel ~= nil then
		self.roleInfoPanel:dispose();
		self.roleInfoPanel = nil;
	end
	if self.myRankNum ~= nil then
		self.myRankNum:dispose();
		self.myRankNum = nil;
	end
	if self.topRankList ~= nil then
		for i = 1, #self.topRankList do
			self.topRankList[i]:dispose();
			self.topRankList[i] = nil;
		end
		self.topRankList = nil;
	end
	if self.rankList ~= nil then
		self.rankList:dispose();
		self.rankList = nil;
	end
	self:superCall("dispose");
end









--------------------------排行榜top3Vo----------------------
Lua_CollectionBookRankTopItem = class("Lua_CollectionBookRankTopItem", Lua_DisplayObject);
function Lua_CollectionBookRankTopItem:ctor(p, index)
	local skinName;
	if index == 1 then
		skinName = "CollectBookRankTopFirstItem_skin";
	elseif index == 2 then
		skinName = "CollectBookRankTopSecondItem_skin";
	else
		skinName = "CollectBookRankTopThirdItem_skin";
	end
	self.rankIndex = index;
    self:superCall("ctor", p, skinName);
end

function Lua_CollectionBookRankTopItem:buildShowItem()
	self:superCall("buildShowItem");

	self.avatarItem = Lua_AvatarItem.new(self.content);
	self.avatarItem:setAvatarClick(self, self.onAvatarClick);

	if self.rankIndex == 1 then
		self:setLocation(9, -360);
		self.avatarItem:setScale(0.82, 0.82);
		self.avatarItem:setLocation(-9, 104);
	elseif self.rankIndex == 2 then
		self:setLocation(-230, -360);
		self.avatarItem:setScale(0.7, 0.7);
		self.avatarItem:setLocation(-7, 91);
	else
		self:setLocation(242, -360);
		self.avatarItem:setScale(0.7, 0.7);
		self.avatarItem:setLocation(-8, 89);
	end

	self.shareIcon:addClickFuntion(self, self.onClickShareIcon);
	self.adirmeIcon:addClickFuntion(self, self.onClickAdmireIcon);
end

function Lua_CollectionBookRankTopItem:setData(data)
	if data == nil then
		return;
	end

	self.adirmeCountTxt.text = data.like_num;
	if data.player_show == nil then
		self.playerId = nil;
		self.isMyself = nil;
		self.canAdmire = nil;
		self.nameText:setLangValue(410020);
		self.descTxt_1.text = nil;
		self.descTxt_2.text = nil;
		self.adirmeIcon:setEnable(false);
		self.shareIcon:setEnable(false);
		self.avatarItem:init();
	else
		self.playerId = tonumber(data.player_show.id);
		self.server_flag = data.player_show.server_flag;
		self.isMyself = DataCenter.roleData:isMyself(self.playerId);
		self.canAdmire = data.is_like == 0;
		self.playerInfo = data.player_show;
		self.nameText.text = data.player_show.name;
		self.descTxt_1.text = LanUtil.formateStr(410021, data.card_amount);
		self.descTxt_2.text = LanUtil.formateStr(410022, data.flash_amount);
		self.adirmeIcon:setEnable(true);
		self.shareIcon:setEnable(true);

		self.avatarItem:setRoleId(data.player_show.id);
		self.avatarItem:setRoleDressUp(data.player_show.dress_info, true);
		self.avatarItem:setRoleLevel2(data.player_show.level);
	end
	local bShow = self.canAdmire and not DataCenter.roleData:isMyself(self.playerId) and DataCenter.collectionBookData.residueAdmireCount > 0;
	self:showRedDot(bShow, self.rankIndex);
end

function Lua_CollectionBookRankTopItem:onAvatarClick()
	if self.playerId == nil then
		return;
	end

	if self.isMyself then
		OperateAlert.showLangValue(410023);
	else
		Lua_ProxyManager.getProxy("Lua_RoleProxy"):sOtherRoleId(self.playerId, self.server_flag);
	end
end

function Lua_CollectionBookRankTopItem:onClickShareIcon()
	DataCenter.collectionBookData:setOtherPlayerInfo(self.playerInfo);
	Lua_ProxyManager.getProxy("Lua_CollectionBookProxy"):sFindOtherCards(self.playerId, self.server_flag);
end

function Lua_CollectionBookRankTopItem:onClickAdmireIcon()
	if DataCenter.collectionBookData.residueAdmireCount <= 0 then
		OperateAlert.showLangValue(410005);
		return;
	end

	if self.isMyself then
		OperateAlert.showLangValue(410007);
	elseif self.isMyself ~= nil then
		if self.canAdmire then
			Lua_ProxyManager.getProxy("Lua_CollectionBookProxy"):sAdmireOtherPlayer(self.playerId, self.server_flag);
		else
			OperateAlert.showLangValue(410006);
		end
	end
end

function Lua_CollectionBookRankTopItem:showRedDot(bShow, index)
	if bShow == true then
		if self.redPoint == nil then
			self.redPoint = Lua_RedPointIcon.new(self.content);
			local posX, posY;
			if self.rankIndex == 1 then
				posX, posY = 43, -99;
			elseif self.rankIndex == 2 then
				posX, posY = 42, -76;
			elseif self.rankIndex == 3 then
				posX, posY = 45, -76;
			end
			self.redPoint:setLocation(posX, posY, 0);
			self.redPoint:createRedPointEff();
		end
		self.redPoint:updateRedPointShow(true);
	else
		if self.redPoint ~= nil then
			self.redPoint:updateRedPointShow(false);
		end
	end
end

function Lua_CollectionBookRankTopItem:dispose()
	if self.avatarItem ~= nil then
		self.avatarItem:dispose();
		self.avatarItem = nil;
	end
	if self.redPoint ~= nil then
		self.redPoint:dispose();
		self.redPoint = nil;
	end
	self:superCall("dispose");
end





















--------------------------排行榜非top3Vo----------------------
Lua_CollectionBookRankItem = class("Lua_CollectionBookRankItem", Lua_ListCell);
function Lua_CollectionBookRankItem:ctor(p)
    self:superCall("ctor", p, "CollectBookRankItem_skin");
end

function Lua_CollectionBookRankItem:buildShowItem()
	self:superCall("buildShowItem");

	self.avatarItem = Lua_AvatarItem.new(self.content);
	self.avatarItem:setScale(0.7, 0.7);
	self.avatarItem:setLocation(-149, 0, 0);
	self.avatarItem:setAvatarClick(self, self.onAvatarClick);

	self.shareIcon:addClickFuntion(self, self.onClickShareIcon);
	self.admireSp:addClickFuntion(self, self.onClickAdmireSp);
end

function Lua_CollectionBookRankItem:setData(data)
	if data == nil then
		return;
	end

	self.rankNumTxt.text = data.rank;
	if data.player_show == nil then
		self.playerId = nil;
		self.isMyself = nil;
		self.canAdmire = nil;


		self.nonePlayerTxt:setLangValue(410020);
		self.nameTxt.text = nil;
		self.descTxt_1.text = nil;
		self.descTxt_2.text = nil;
		self.admireCountTxt.text = nil;
		self.shareIcon:setEnable(false);
		self.rankSplitSp_1:setEnable(false);
		self.rankSplitSp_2:setEnable(false);
		self.admireSp:setEnable(false);
		-- self.avatarItem:init();
		self.avatarItem:setEnable(false);
	else
		self.playerId = tonumber(data.player_show.id);
		self.server_flag = data.player_show.server_flag;
		self.isMyself = DataCenter.roleData:isMyself(self.playerId);
		self.canAdmire = data.is_like == 0;
		self.playerInfo = data.player_show;

		self.nonePlayerTxt.text = nil;
		self.nameTxt.text = data.player_show.name;
		self.descTxt_1.text = LanUtil.formateStr(410021, data.card_amount);
		self.descTxt_2.text = LanUtil.formateStr(410022, data.flash_amount);
		self.admireCountTxt.text = data.like_num;

		self.avatarItem:setEnable(true);
		self.avatarItem:setRoleId(data.player_show.id);
		self.avatarItem:setRoleDressUp(data.player_show.dress_info, true);
		self.avatarItem:setRoleLevel2(data.player_show.level);

		self.shareIcon:setEnable(true);
		self.rankSplitSp_1:setEnable(true);
		self.rankSplitSp_2:setEnable(true);
		self.admireSp:setEnable(true);
		if self.canAdmire then
			self.admireSp:setAltas("rank_altas", "xui_phb_btn_3_n");
		else
			self.admireSp:setAltas("rank_altas", "xui_phb_btn_3_p");
		end
	end
end

function Lua_CollectionBookRankItem:onAvatarClick()
	if self.playerId == nil then
		return;
	end

	if self.isMyself then
		OperateAlert.showLangValue(410023);
	else
		Lua_ProxyManager.getProxy("Lua_RoleProxy"):sOtherRoleId(self.playerId, self.server_flag);
	end
end

function Lua_CollectionBookRankItem:onClickShareIcon()
	DataCenter.collectionBookData:setOtherPlayerInfo(self.playerInfo);
	Lua_ProxyManager.getProxy("Lua_CollectionBookProxy"):sFindOtherCards(self.playerId, self.server_flag);
end

function Lua_CollectionBookRankItem:onClickAdmireSp()
	if DataCenter.collectionBookData.residueAdmireCount <= 0 then
		OperateAlert.showLangValue(410005);
		return;
	end

	if self.isMyself then
		OperateAlert.showLangValue(410007);
	elseif self.isMyself ~= nil then
		if self.canAdmire then
			Lua_ProxyManager.getProxy("Lua_CollectionBookProxy"):sAdmireOtherPlayer(self.playerId, self.server_flag);
		else
			OperateAlert.showLangValue(410006);
		end
	end
end

function Lua_CollectionBookRankItem:dispose()
	if self.avatarItem ~= nil then
		self.avatarItem:dispose();
		self.avatarItem = nil;
	end
	self:superCall("dispose");
end